=======
History
=======

0.3.0 (2019-03-29)
------------------

* Implement Ranked Pairs rule.

0.2.1 (2019-03-28)
------------------

* Optimize argument passing between child classes, their parent classes and their ``__call__`` function.

0.2.0 (2019-03-21)
------------------

* First "real" release, where most classic voting systems are implemented.

0.1.0 (2018-03-13)
------------------

* First release on PyPI.
